@@ -13,13 +13,13 @@ use Cwd;
 use vars qw( $VERSION @ISA );
 
 BEGIN {
-    $VERSION = '1.38';
+    $VERSION = '1.39';
     @ISA     = qw( Archive::Zip );
 
-    if ( $^O eq 'MSWin32' ) {
+    if ($^O eq 'MSWin32') {
         require Win32;
         require Encode;
-        Encode->import( qw{ encode_utf8 decode_utf8 } );
+        Encode->import(qw{ encode_utf8 decode_utf8 });
     }
 }
 
@@ -40,11 +40,12 @@ sub new {
         {
             'diskNumber'                            => 0,
             'diskNumberWithStartOfCentralDirectory' => 0,
-            'numberOfCentralDirectoriesOnThisDisk'  => 0, # should be # of members
-            'numberOfCentralDirectories'            => 0, # should be # of members
-            'centralDirectorySize' => 0,    # must re-compute on write
+            'numberOfCentralDirectoriesOnThisDisk' =>
+              0,    # should be # of members
+            'numberOfCentralDirectories' => 0,    # should be # of members
+            'centralDirectorySize'       => 0,    # must re-compute on write
             'centralDirectoryOffsetWRTStartingDiskNumber' =>
-              0,                            # must re-compute
+              0,                                  # must re-compute
             'writeEOCDOffset'             => 0,
             'writeCentralDirectoryOffset' => 0,
             'zipfileComment'              => '',
@@ -54,7 +55,7 @@ sub new {
         $class
     );
     $self->{'members'} = [];
-    my $fileName = ( ref( $_[0] ) eq 'HASH' ) ? shift->{filename} : shift;
+    my $fileName = (ref($_[0]) eq 'HASH') ? shift->{filename} : shift;
     if ($fileName) {
         my $status = $self->read($fileName);
         return $status == AZ_OK ? $self : undef;
@@ -68,11 +69,11 @@ sub storeSymbolicLink {
 }
 
 sub members {
-    @{ shift->{'members'} };
+    @{shift->{'members'}};
 }
 
 sub numberOfMembers {
-    scalar( shift->members() );
+    scalar(shift->members());
 }
 
 sub memberNames {
@@ -82,17 +83,17 @@ sub memberNames {
 
 # return ref to member with given name or undef
 sub memberNamed {
-    my $self     = shift;
-    my $fileName = ( ref( $_[0] ) eq 'HASH' ) ? shift->{zipName} : shift;
-    foreach my $member ( $self->members() ) {
+    my $self = shift;
+    my $fileName = (ref($_[0]) eq 'HASH') ? shift->{zipName} : shift;
+    foreach my $member ($self->members()) {
         return $member if $member->fileName() eq $fileName;
     }
     return undef;
 }
 
 sub membersMatching {
-    my $self    = shift;
-    my $pattern = ( ref( $_[0] ) eq 'HASH' ) ? shift->{regex} : shift;
+    my $self = shift;
+    my $pattern = (ref($_[0]) eq 'HASH') ? shift->{regex} : shift;
     return grep { $_->fileName() =~ /$pattern/ } $self->members();
 }
 
@@ -124,8 +125,8 @@ sub zipfileComment {
     my $self    = shift;
     my $comment = $self->{'zipfileComment'};
     if (@_) {
-        my $new_comment = ( ref( $_[0] ) eq 'HASH' ) ? shift->{comment} : shift;
-        $self->{'zipfileComment'} = pack( 'C0a*', $new_comment );    # avoid Unicode
+        my $new_comment = (ref($_[0]) eq 'HASH') ? shift->{comment} : shift;
+        $self->{'zipfileComment'} = pack('C0a*', $new_comment);  # avoid Unicode
     }
     return $comment;
 }
@@ -140,8 +141,8 @@ sub fileName {
 }
 
 sub removeMember {
-    my $self    = shift;
-    my $member  = ( ref( $_[0] ) eq 'HASH' ) ? shift->{memberOrZipName} : shift;
+    my $self = shift;
+    my $member = (ref($_[0]) eq 'HASH') ? shift->{memberOrZipName} : shift;
     $member = $self->memberNamed($member) unless ref($member);
     return undef unless $member;
     my @newMembers = grep { $_ != $member } $self->members();
@@ -152,20 +153,19 @@ sub removeMember {
 sub replaceMember {
     my $self = shift;
 
-    my ( $oldMember, $newMember );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($oldMember, $newMember);
+    if (ref($_[0]) eq 'HASH') {
         $oldMember = $_[0]->{memberOrZipName};
         $newMember = $_[0]->{newMember};
-    }
-    else {
-        ( $oldMember, $newMember ) = @_;
+    } else {
+        ($oldMember, $newMember) = @_;
     }
 
     $oldMember = $self->memberNamed($oldMember) unless ref($oldMember);
     return undef unless $oldMember;
     return undef unless $newMember;
     my @newMembers =
-      map { ( $_ == $oldMember ) ? $newMember : $_ } $self->members();
+      map { ($_ == $oldMember) ? $newMember : $_ } $self->members();
     $self->{'members'} = \@newMembers;
     return $oldMember;
 }
@@ -173,34 +173,32 @@ sub replaceMember {
 sub extractMember {
     my $self = shift;
 
-    my ( $member, $name );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($member, $name);
+    if (ref($_[0]) eq 'HASH') {
         $member = $_[0]->{memberOrZipName};
         $name   = $_[0]->{name};
-    }
-    else {
-        ( $member, $name ) = @_;
+    } else {
+        ($member, $name) = @_;
     }
 
     $member = $self->memberNamed($member) unless ref($member);
     return _error('member not found') unless $member;
     my $originalSize = $member->compressedSize();
-    my ( $volumeName, $dirName, $fileName );
-    if ( defined($name) ) {
-        ( $volumeName, $dirName, $fileName ) = File::Spec->splitpath($name);
-        $dirName = File::Spec->catpath( $volumeName, $dirName, '' );
-    }
-    else {
+    my ($volumeName, $dirName, $fileName);
+    if (defined($name)) {
+        ($volumeName, $dirName, $fileName) = File::Spec->splitpath($name);
+        $dirName = File::Spec->catpath($volumeName, $dirName, '');
+    } else {
         $name = $member->fileName();
-        ( $dirName = $name ) =~ s{[^/]*$}{};
+        ($dirName = $name) =~ s{[^/]*$}{};
         $dirName = Archive::Zip::_asLocalName($dirName);
         $name    = Archive::Zip::_asLocalName($name);
     }
-    if ( $dirName && !-d $dirName ) {
+    if ($dirName && !-d $dirName) {
         mkpath($dirName);
-        return _ioError("can't create dir $dirName") if ( !-d $dirName );
+        return _ioError("can't create dir $dirName") if (!-d $dirName);
     }
-    my $rc = $member->extractToFileNamed( $name, @_ );
+    my $rc = $member->extractToFileNamed($name, @_);
 
     # TODO refactor this fix into extractToFileNamed()
     $member->{'compressedSize'} = $originalSize;
@@ -210,13 +208,12 @@ sub extractMember {
 sub extractMemberWithoutPaths {
     my $self = shift;
 
-    my ( $member, $name );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($member, $name);
+    if (ref($_[0]) eq 'HASH') {
         $member = $_[0]->{memberOrZipName};
         $name   = $_[0]->{name};
-    }
-    else {
-        ( $member, $name ) = @_;
+    } else {
+        ($member, $name) = @_;
     }
 
     $member = $self->memberNamed($member) unless ref($member);
@@ -228,47 +225,49 @@ sub extractMemberWithoutPaths {
         $name =~ s{.*/}{};    # strip off directories, if any
         $name = Archive::Zip::_asLocalName($name);
     }
-    my $rc = $member->extractToFileNamed( $name, @_ );
+    my $rc = $member->extractToFileNamed($name, @_);
     $member->{'compressedSize'} = $originalSize;
     return $rc;
 }
 
 sub addMember {
-    my $self       = shift;
-    my $newMember  = ( ref( $_[0] ) eq 'HASH' ) ? shift->{member} : shift;
-    push( @{ $self->{'members'} }, $newMember ) if $newMember;
+    my $self = shift;
+    my $newMember = (ref($_[0]) eq 'HASH') ? shift->{member} : shift;
+    push(@{$self->{'members'}}, $newMember) if $newMember;
     return $newMember;
 }
 
 sub addFile {
     my $self = shift;
 
-    my ( $fileName, $newName, $compressionLevel );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($fileName, $newName, $compressionLevel);
+    if (ref($_[0]) eq 'HASH') {
         $fileName         = $_[0]->{filename};
         $newName          = $_[0]->{zipName};
         $compressionLevel = $_[0]->{compressionLevel};
-    }
-    else {
-        ( $fileName, $newName, $compressionLevel ) = @_;
+    } else {
+        ($fileName, $newName, $compressionLevel) = @_;
     }
 
-    if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
+    if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
         $fileName = Win32::GetANSIPathName($fileName);
     }
 
-    my $newMember = $self->ZIPMEMBERCLASS->newFromFile( $fileName, $newName );
+    my $newMember = Archive::Zip::Member->newFromFile($fileName, $newName);
     $newMember->desiredCompressionLevel($compressionLevel);
-    if ( $self->{'storeSymbolicLink'} && -l $fileName ) {
-        my $newMember = $self->ZIPMEMBERCLASS->newFromString(readlink $fileName, $newName);
-        # For symbolic links, External File Attribute is set to 0xA1FF0000 by Info-ZIP
+    if ($self->{'storeSymbolicLink'} && -l $fileName) {
+        my $newMember =
+          Archive::Zip::Member->newFromString(readlink $fileName, $newName);
+
+  # For symbolic links, External File Attribute is set to 0xA1FF0000 by Info-ZIP
         $newMember->{'externalFileAttributes'} = 0xA1FF0000;
         $self->addMember($newMember);
     } else {
         $self->addMember($newMember);
     }
-    if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
-        $newMember->{'fileName'} = encode_utf8( Win32::GetLongPathName($fileName) );
+    if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
+        $newMember->{'fileName'} =
+          encode_utf8(Win32::GetLongPathName($fileName));
     }
     return $newMember;
 }
@@ -276,19 +275,17 @@ sub addFile {
 sub addString {
     my $self = shift;
 
-    my ( $stringOrStringRef, $name, $compressionLevel );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($stringOrStringRef, $name, $compressionLevel);
+    if (ref($_[0]) eq 'HASH') {
         $stringOrStringRef = $_[0]->{string};
         $name              = $_[0]->{zipName};
         $compressionLevel  = $_[0]->{compressionLevel};
-    }
-    else {
-        ( $stringOrStringRef, $name, $compressionLevel ) = @_;;
+    } else {
+        ($stringOrStringRef, $name, $compressionLevel) = @_;
     }
 
-    my $newMember = $self->ZIPMEMBERCLASS->newFromString(
-        $stringOrStringRef, $name
-    );
+    my $newMember =
+      Archive::Zip::Member->newFromString($stringOrStringRef, $name);
     $newMember->desiredCompressionLevel($compressionLevel);
     return $self->addMember($newMember);
 }
@@ -296,32 +293,32 @@ sub addString {
 sub addDirectory {
     my $self = shift;
 
-    my ( $name, $newName );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($name, $newName);
+    if (ref($_[0]) eq 'HASH') {
         $name    = $_[0]->{directoryName};
         $newName = $_[0]->{zipName};
-    }
-    else {
-        ( $name, $newName ) = @_;
+    } else {
+        ($name, $newName) = @_;
     }
 
-    if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
+    if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
         $name = Win32::GetANSIPathName($name);
     }
 
-    my $newMember = $self->ZIPMEMBERCLASS->newDirectoryNamed( $name, $newName );
-    if ( $self->{'storeSymbolicLink'} && -l $name ) {
+    my $newMember = Archive::Zip::Member->newDirectoryNamed($name, $newName);
+    if ($self->{'storeSymbolicLink'} && -l $name) {
         my $link = readlink $name;
-        ( $newName =~ s{/$}{} ) if $newName; # Strip trailing /
-        my $newMember = $self->ZIPMEMBERCLASS->newFromString($link, $newName);
-        # For symbolic links, External File Attribute is set to 0xA1FF0000 by Info-ZIP
+        ($newName =~ s{/$}{}) if $newName;    # Strip trailing /
+        my $newMember = Archive::Zip::Member->newFromString($link, $newName);
+
+  # For symbolic links, External File Attribute is set to 0xA1FF0000 by Info-ZIP
         $newMember->{'externalFileAttributes'} = 0xA1FF0000;
         $self->addMember($newMember);
     } else {
         $self->addMember($newMember);
     }
-    if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
-        $newMember->{'fileName'} = encode_utf8( Win32::GetLongPathName($name) );
+    if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
+        $newMember->{'fileName'} = encode_utf8(Win32::GetLongPathName($name));
     }
     return $newMember;
 }
@@ -331,33 +328,30 @@ sub addDirectory {
 sub addFileOrDirectory {
     my $self = shift;
 
-    my ( $name, $newName, $compressionLevel );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($name, $newName, $compressionLevel);
+    if (ref($_[0]) eq 'HASH') {
         $name             = $_[0]->{name};
         $newName          = $_[0]->{zipName};
         $compressionLevel = $_[0]->{compressionLevel};
-    }
-    else {
-        ( $name, $newName, $compressionLevel ) = @_;
+    } else {
+        ($name, $newName, $compressionLevel) = @_;
     }
 
-    if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
+    if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
         $name = Win32::GetANSIPathName($name);
     }
 
     $name =~ s{/$}{};
-    if ( $newName ) {
+    if ($newName) {
         $newName =~ s{/$}{};
     } else {
         $newName = $name;
     }
-    if ( -f $name ) {
-        return $self->addFile( $name, $newName, $compressionLevel );
-    }
-    elsif ( -d $name ) {
-        return $self->addDirectory( $name, $newName );
-    }
-    else {
+    if (-f $name) {
+        return $self->addFile($name, $newName, $compressionLevel);
+    } elsif (-d $name) {
+        return $self->addDirectory($name, $newName);
+    } else {
         return _error("$name is neither a file nor a directory");
     }
 }
@@ -365,13 +359,12 @@ sub addFileOrDirectory {
 sub contents {
     my $self = shift;
 
-    my ( $member, $newContents );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($member, $newContents);
+    if (ref($_[0]) eq 'HASH') {
         $member      = $_[0]->{memberOrZipName};
         $newContents = $_[0]->{contents};
-    }
-    else {
-        ( $member, $newContents ) = @_;
+    } else {
+        ($member, $newContents) = @_;
     }
 
     return _error('No member name given') unless $member;
@@ -383,17 +376,17 @@ sub contents {
 sub writeToFileNamed {
     my $self = shift;
     my $fileName =
-      ( ref( $_[0] ) eq 'HASH' ) ? shift->{filename} : shift;  # local FS format
-    foreach my $member ( $self->members() ) {
-        if ( $member->_usesFileNamed($fileName) ) {
-            return _error( "$fileName is needed by member "
+      (ref($_[0]) eq 'HASH') ? shift->{filename} : shift;    # local FS format
+    foreach my $member ($self->members()) {
+        if ($member->_usesFileNamed($fileName)) {
+            return _error("$fileName is needed by member "
                   . $member->fileName()
-                  . "; consider using overwrite() or overwriteAs() instead." );
+                  . "; consider using overwrite() or overwriteAs() instead.");
         }
     }
-    my ( $status, $fh ) = _newFileHandle( $fileName, 'w' );
+    my ($status, $fh) = _newFileHandle($fileName, 'w');
     return _ioError("Can't open $fileName for write") unless $status;
-    my $retval = $self->writeToFileHandle( $fh, 1 );
+    my $retval = $self->writeToFileHandle($fh, 1);
     $fh->close();
     $fh = undef;
 
@@ -405,14 +398,13 @@ sub writeToFileNamed {
 sub writeToFileHandle {
     my $self = shift;
 
-    my ( $fh, $fhIsSeekable );
-    if ( ref( $_[0] ) eq 'HASH' ) {
-        $fh           = $_[0]->{fileHandle};
+    my ($fh, $fhIsSeekable);
+    if (ref($_[0]) eq 'HASH') {
+        $fh = $_[0]->{fileHandle};
         $fhIsSeekable =
-          exists( $_[0]->{seek} ) ? $_[0]->{seek} : _isSeekable($fh);
-    }
-    else {
-        $fh           = shift;
+          exists($_[0]->{seek}) ? $_[0]->{seek} : _isSeekable($fh);
+    } else {
+        $fh = shift;
         $fhIsSeekable = @_ ? shift : _isSeekable($fh);
     }
 
@@ -422,10 +414,10 @@ sub writeToFileHandle {
 
     # Find out where the current position is.
     my $offset = $fhIsSeekable ? $fh->tell() : 0;
-    $offset    = 0 if $offset < 0;
+    $offset = 0 if $offset < 0;
 
-    foreach my $member ( $self->members() ) {
-        my $retval = $member->_writeToFileHandle( $fh, $fhIsSeekable, $offset );
+    foreach my $member ($self->members()) {
+        my $retval = $member->_writeToFileHandle($fh, $fhIsSeekable, $offset);
         $member->endRead();
         return $retval if $retval != AZ_OK;
         $offset += $member->_localHeaderSize() + $member->_writeOffset();
@@ -445,27 +437,27 @@ sub writeToFileHandle {
 # Returns AZ_OK if successful.
 sub overwrite {
     my $self = shift;
-    return $self->overwriteAs( $self->{'fileName'} );
+    return $self->overwriteAs($self->{'fileName'});
 }
 
 # Write zip to the specified file,
 # as safely as possible.
 # Returns AZ_OK if successful.
 sub overwriteAs {
-    my $self    = shift;
-    my $zipName = ( ref( $_[0] ) eq 'HASH' ) ? $_[0]->{filename} : shift;
+    my $self = shift;
+    my $zipName = (ref($_[0]) eq 'HASH') ? $_[0]->{filename} : shift;
     return _error("no filename in overwriteAs()") unless defined($zipName);
 
-    my ( $fh, $tempName ) = Archive::Zip::tempFile();
-    return _error( "Can't open temp file", $! ) unless $fh;
+    my ($fh, $tempName) = Archive::Zip::tempFile();
+    return _error("Can't open temp file", $!) unless $fh;
 
-    ( my $backupName = $zipName ) =~ s{(\.[^.]*)?$}{.zbk};
+    (my $backupName = $zipName) =~ s{(\.[^.]*)?$}{.zbk};
 
     my $status = $self->writeToFileHandle($fh);
     $fh->close();
     $fh = undef;
 
-    if ( $status != AZ_OK ) {
+    if ($status != AZ_OK) {
         unlink($tempName);
         _printError("Can't write to $tempName");
         return $status;
@@ -474,24 +466,25 @@ sub overwriteAs {
     my $err;
 
     # rename the zip
-    if ( -f $zipName && !rename( $zipName, $backupName ) ) {
+    if (-f $zipName && !rename($zipName, $backupName)) {
         $err = $!;
         unlink($tempName);
-        return _error( "Can't rename $zipName as $backupName", $err );
+        return _error("Can't rename $zipName as $backupName", $err);
     }
 
     # move the temp to the original name (possibly copying)
-    unless ( File::Copy::move( $tempName, $zipName ) || File::Copy::copy( $tempName, $zipName) ) {
+    unless (File::Copy::move($tempName, $zipName)
+        || File::Copy::copy($tempName, $zipName)) {
         $err = $!;
-        rename( $backupName, $zipName );
+        rename($backupName, $zipName);
         unlink($tempName);
-        return _error( "Can't move $tempName to $zipName", $err );
+        return _error("Can't move $tempName to $zipName", $err);
     }
 
     # unlink the backup
-    if ( -f $backupName && !unlink($backupName) ) {
+    if (-f $backupName && !unlink($backupName)) {
         $err = $!;
-        return _error( "Can't unlink $backupName", $err );
+        return _error("Can't unlink $backupName", $err);
     }
 
     return AZ_OK;
@@ -508,11 +501,11 @@ sub _writeEOCDOffset {
 
 # Expects to have _writeEOCDOffset() set
 sub _writeEndOfCentralDirectory {
-    my ( $self, $fh ) = @_;
+    my ($self, $fh) = @_;
 
     $self->_print($fh, END_OF_CENTRAL_DIRECTORY_SIGNATURE_STRING)
       or return _ioError('writing EOCD Signature');
-    my $zipfileCommentLength = length( $self->zipfileComment() );
+    my $zipfileCommentLength = length($self->zipfileComment());
 
     my $header = pack(
         END_OF_CENTRAL_DIRECTORY_FORMAT,
@@ -527,7 +520,7 @@ sub _writeEndOfCentralDirectory {
     $self->_print($fh, $header)
       or return _ioError('writing EOCD header');
     if ($zipfileCommentLength) {
-        $self->_print($fh,  $self->zipfileComment() )
+        $self->_print($fh, $self->zipfileComment())
           or return _ioError('writing zipfile comment');
     }
     return AZ_OK;
@@ -537,25 +530,23 @@ sub _writeEndOfCentralDirectory {
 sub writeCentralDirectory {
     my $self = shift;
 
-    my ( $fh, $offset );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($fh, $offset);
+    if (ref($_[0]) eq 'HASH') {
         $fh     = $_[0]->{fileHandle};
         $offset = $_[0]->{offset};
-    }
-    else {
-        ( $fh, $offset ) = @_;
+    } else {
+        ($fh, $offset) = @_;
     }
 
-    if ( defined($offset) ) {
+    if (defined($offset)) {
         $self->{'writeCentralDirectoryOffset'} = $offset;
-        $fh->seek( $offset, IO::Seekable::SEEK_SET )
+        $fh->seek($offset, IO::Seekable::SEEK_SET)
           or return _ioError('seeking to write central directory');
-    }
-    else {
+    } else {
         $offset = $self->_writeCentralDirectoryOffset();
     }
 
-    foreach my $member ( $self->members() ) {
+    foreach my $member ($self->members()) {
         my $status = $member->_writeCentralDirectoryFileHeader($fh);
         return $status if $status != AZ_OK;
         $offset += $member->_centralDirectoryHeaderSize();
@@ -565,13 +556,13 @@ sub writeCentralDirectory {
 }
 
 sub read {
-    my $self     = shift;
-    my $fileName = ( ref( $_[0] ) eq 'HASH' ) ? shift->{filename} : shift;
+    my $self = shift;
+    my $fileName = (ref($_[0]) eq 'HASH') ? shift->{filename} : shift;
     return _error('No filename given') unless $fileName;
-    my ( $status, $fh ) = _newFileHandle( $fileName, 'r' );
+    my ($status, $fh) = _newFileHandle($fileName, 'r');
     return _ioError("opening $fileName for read") unless $status;
 
-    $status = $self->readFromFileHandle( $fh, $fileName );
+    $status = $self->readFromFileHandle($fh, $fileName);
     return $status if $status != AZ_OK;
 
     $fh->close();
@@ -582,13 +573,12 @@ sub read {
 sub readFromFileHandle {
     my $self = shift;
 
-    my ( $fh, $fileName );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($fh, $fileName);
+    if (ref($_[0]) eq 'HASH') {
         $fh       = $_[0]->{fileHandle};
         $fileName = $_[0]->{filename};
-    }
-    else {
-        ( $fh, $fileName ) = @_;
+    } else {
+        ($fh, $fileName) = @_;
     }
 
     $fileName = $fh unless defined($fileName);
@@ -602,7 +592,7 @@ sub readFromFileHandle {
     return _error('file not seekable')
       unless _isSeekable($fh);
 
-    $fh->seek( 0, 0 );    # rewind the file
+    $fh->seek(0, 0);    # rewind the file
 
     my $status = $self->_findEndOfCentralDirectory($fh);
     return $status if $status != AZ_OK;
@@ -612,8 +602,8 @@ sub readFromFileHandle {
     $status = $self->_readEndOfCentralDirectory($fh);
     return $status if $status != AZ_OK;
 
-    $fh->seek( $eocdPosition - $self->centralDirectorySize(),
-        IO::Seekable::SEEK_SET )
+    $fh->seek($eocdPosition - $self->centralDirectorySize(),
+        IO::Seekable::SEEK_SET)
       or return _ioError("Can't seek $fileName");
 
     # Try to detect garbage at beginning of archives
@@ -621,20 +611,20 @@ sub readFromFileHandle {
     $self->{'eocdOffset'} = $eocdPosition - $self->centralDirectorySize() # here
       - $self->centralDirectoryOffsetWRTStartingDiskNumber();
 
-    for ( ; ; ) {
+    for (; ;) {
         my $newMember =
-          $self->ZIPMEMBERCLASS->_newFromZipFile( $fh, $fileName,
-            $self->eocdOffset() );
+          Archive::Zip::Member->_newFromZipFile($fh, $fileName,
+            $self->eocdOffset());
         my $signature;
-        ( $status, $signature ) = _readSignature( $fh, $fileName );
+        ($status, $signature) = _readSignature($fh, $fileName);
         return $status if $status != AZ_OK;
-        last           if $signature == END_OF_CENTRAL_DIRECTORY_SIGNATURE;
+        last if $signature == END_OF_CENTRAL_DIRECTORY_SIGNATURE;
         $status = $newMember->_readCentralDirectoryFileHeader();
         return $status if $status != AZ_OK;
         $status = $newMember->endRead();
         return $status if $status != AZ_OK;
         $newMember->_becomeDirectoryIfNecessary();
-        push( @{ $self->{'members'} }, $newMember );
+        push(@{$self->{'members'}}, $newMember);
     }
 
     return AZ_OK;
@@ -647,12 +637,12 @@ sub _readEndOfCentralDirectory {
     my $fh   = shift;
 
     # Skip past signature
-    $fh->seek( SIGNATURE_LENGTH, IO::Seekable::SEEK_CUR )
+    $fh->seek(SIGNATURE_LENGTH, IO::Seekable::SEEK_CUR)
       or return _ioError("Can't seek past EOCD signature");
 
     my $header = '';
-    my $bytesRead = $fh->read( $header, END_OF_CENTRAL_DIRECTORY_LENGTH );
-    if ( $bytesRead != END_OF_CENTRAL_DIRECTORY_LENGTH ) {
+    my $bytesRead = $fh->read($header, END_OF_CENTRAL_DIRECTORY_LENGTH);
+    if ($bytesRead != END_OF_CENTRAL_DIRECTORY_LENGTH) {
         return _ioError("reading end of central directory");
     }
 
@@ -665,12 +655,12 @@ sub _readEndOfCentralDirectory {
         $self->{'centralDirectorySize'},
         $self->{'centralDirectoryOffsetWRTStartingDiskNumber'},
         $zipfileCommentLength
-    ) = unpack( END_OF_CENTRAL_DIRECTORY_FORMAT, $header );
+    ) = unpack(END_OF_CENTRAL_DIRECTORY_FORMAT, $header);
 
     if ($zipfileCommentLength) {
         my $zipfileComment = '';
-        $bytesRead = $fh->read( $zipfileComment, $zipfileCommentLength );
-        if ( $bytesRead != $zipfileCommentLength ) {
+        $bytesRead = $fh->read($zipfileComment, $zipfileCommentLength);
+        if ($bytesRead != $zipfileCommentLength) {
             return _ioError("reading zipfile comment");
         }
         $self->{'zipfileComment'} = $zipfileComment;
@@ -686,38 +676,37 @@ sub _findEndOfCentralDirectory {
     my $self = shift;
     my $fh   = shift;
     my $data = '';
-    $fh->seek( 0, IO::Seekable::SEEK_END )
+    $fh->seek(0, IO::Seekable::SEEK_END)
       or return _ioError("seeking to end");
 
     my $fileLength = $fh->tell();
-    if ( $fileLength < END_OF_CENTRAL_DIRECTORY_LENGTH + 4 ) {
+    if ($fileLength < END_OF_CENTRAL_DIRECTORY_LENGTH + 4) {
         return _formatError("file is too short");
     }
 
     my $seekOffset = 0;
     my $pos        = -1;
-    for ( ; ; ) {
+    for (; ;) {
         $seekOffset += 512;
-        $seekOffset = $fileLength if ( $seekOffset > $fileLength );
-        $fh->seek( -$seekOffset, IO::Seekable::SEEK_END )
+        $seekOffset = $fileLength if ($seekOffset > $fileLength);
+        $fh->seek(-$seekOffset, IO::Seekable::SEEK_END)
           or return _ioError("seek failed");
-        my $bytesRead = $fh->read( $data, $seekOffset );
-        if ( $bytesRead != $seekOffset ) {
+        my $bytesRead = $fh->read($data, $seekOffset);
+        if ($bytesRead != $seekOffset) {
             return _ioError("read failed");
         }
-        $pos = rindex( $data, END_OF_CENTRAL_DIRECTORY_SIGNATURE_STRING );
+        $pos = rindex($data, END_OF_CENTRAL_DIRECTORY_SIGNATURE_STRING);
         last
           if ( $pos >= 0
             or $seekOffset == $fileLength
-            or $seekOffset >= $Archive::Zip::ChunkSize );
+            or $seekOffset >= $Archive::Zip::ChunkSize);
     }
 
-    if ( $pos >= 0 ) {
-        $fh->seek( $pos - $seekOffset, IO::Seekable::SEEK_CUR )
+    if ($pos >= 0) {
+        $fh->seek($pos - $seekOffset, IO::Seekable::SEEK_CUR)
           or return _ioError("seeking to EOCD");
         return AZ_OK;
-    }
-    else {
+    } else {
         return _formatError("can't find EOCD signature");
     }
 }
@@ -735,26 +724,26 @@ sub _untaintDir {
 sub addTree {
     my $self = shift;
 
-    my ( $root, $dest, $pred, $compressionLevel );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($root, $dest, $pred, $compressionLevel);
+    if (ref($_[0]) eq 'HASH') {
         $root             = $_[0]->{root};
         $dest             = $_[0]->{zipName};
         $pred             = $_[0]->{select};
         $compressionLevel = $_[0]->{compressionLevel};
-    }
-    else {
-        ( $root, $dest, $pred, $compressionLevel ) = @_;
+    } else {
+        ($root, $dest, $pred, $compressionLevel) = @_;
     }
 
     return _error("root arg missing in call to addTree()")
       unless defined($root);
     $dest = '' unless defined($dest);
-    $pred = sub { -r } unless defined($pred);
+    $pred = sub { -r }
+      unless defined($pred);
 
     my @files;
-    my $startDir = _untaintDir( cwd() );
+    my $startDir = _untaintDir(cwd());
 
-    return _error( 'undef returned by _untaintDir on cwd ', cwd() )
+    return _error('undef returned by _untaintDir on cwd ', cwd())
       unless $startDir;
 
     # This avoids chdir'ing in Find, in a way compatible with older
@@ -763,43 +752,42 @@ sub addTree {
         local $main::_ = $File::Find::name;
         my $dir = _untaintDir($File::Find::dir);
         chdir($startDir);
-        if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
-            push( @files, Win32::GetANSIPathName($File::Find::name) ) if (&$pred);
+        if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
+            push(@files, Win32::GetANSIPathName($File::Find::name)) if (&$pred);
             $dir = Win32::GetANSIPathName($dir);
-        }
-        else {
-            push( @files, $File::Find::name ) if (&$pred);
+        } else {
+            push(@files, $File::Find::name) if (&$pred);
         }
         chdir($dir);
     };
 
-    if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
+    if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
         $root = Win32::GetANSIPathName($root);
     }
-    File::Find::find( $wanted, $root );
+    File::Find::find($wanted, $root);
 
-    my $rootZipName = _asZipDirName( $root, 1 );    # with trailing slash
+    my $rootZipName = _asZipDirName($root, 1);    # with trailing slash
     my $pattern = $rootZipName eq './' ? '^' : "^\Q$rootZipName\E";
 
-    $dest = _asZipDirName( $dest, 1 );              # with trailing slash
+    $dest = _asZipDirName($dest, 1);              # with trailing slash
 
     foreach my $fileName (@files) {
         my $isDir;
-        if ( $^O eq 'MSWin32' && $Archive::Zip::UNICODE ) {
+        if ($^O eq 'MSWin32' && $Archive::Zip::UNICODE) {
             $isDir = -d Win32::GetANSIPathName($fileName);
-        }
-        else {
+        } else {
             $isDir = -d $fileName;
         }
 
         # normalize, remove leading ./
-        my $archiveName = _asZipDirName( $fileName, $isDir );
-        if ( $archiveName eq $rootZipName ) { $archiveName = $dest }
-        else { $archiveName =~ s{$pattern}{$dest} }
-        next if $archiveName =~ m{^\.?/?$};         # skip current dir
-        my $member = $isDir
-          ? $self->addDirectory( $fileName, $archiveName )
-          : $self->addFile( $fileName, $archiveName );
+        my $archiveName = _asZipDirName($fileName, $isDir);
+        if ($archiveName eq $rootZipName) { $archiveName = $dest }
+        else                              { $archiveName =~ s{$pattern}{$dest} }
+        next if $archiveName =~ m{^\.?/?$};    # skip current dir
+        my $member =
+            $isDir
+          ? $self->addDirectory($fileName, $archiveName)
+          : $self->addFile($fileName, $archiveName);
         $member->desiredCompressionLevel($compressionLevel);
 
         return _error("add $fileName failed in addTree()") if !$member;
@@ -810,16 +798,15 @@ sub addTree {
 sub addTreeMatching {
     my $self = shift;
 
-    my ( $root, $dest, $pattern, $pred, $compressionLevel );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($root, $dest, $pattern, $pred, $compressionLevel);
+    if (ref($_[0]) eq 'HASH') {
         $root             = $_[0]->{root};
         $dest             = $_[0]->{zipName};
         $pattern          = $_[0]->{pattern};
         $pred             = $_[0]->{select};
         $compressionLevel = $_[0]->{compressionLevel};
-    }
-    else {
-        ( $root, $dest, $pattern, $pred, $compressionLevel ) = @_;
+    } else {
+        ($root, $dest, $pattern, $pred, $compressionLevel) = @_;
     }
 
     return _error("root arg missing in call to addTreeMatching()")
@@ -829,7 +816,7 @@ sub addTreeMatching {
       unless defined($pattern);
     my $matcher =
       $pred ? sub { m{$pattern} && &$pred } : sub { m{$pattern} && -r };
-    return $self->addTree( $root, $dest, $matcher, $compressionLevel );
+    return $self->addTree($root, $dest, $matcher, $compressionLevel);
 }
 
 # $zip->extractTree( $root, $dest [, $volume] );
@@ -840,23 +827,21 @@ sub addTreeMatching {
 sub extractTree {
     my $self = shift;
 
-    my ( $root, $dest, $volume );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($root, $dest, $volume);
+    if (ref($_[0]) eq 'HASH') {
         $root   = $_[0]->{root};
         $dest   = $_[0]->{zipName};
         $volume = $_[0]->{volume};
-    }
-    else {
-        ( $root, $dest, $volume ) = @_;
+    } else {
+        ($root, $dest, $volume) = @_;
     }
 
     $root = '' unless defined($root);
-    if ( defined $dest ) {
-        if ( $dest !~ m{/$} ) {
+    if (defined $dest) {
+        if ($dest !~ m{/$}) {
             $dest .= '/';
         }
-    }
-    else {
+    } else {
         $dest = './';
     }
 
@@ -864,10 +849,10 @@ sub extractTree {
     my @members = $self->membersMatching($pattern);
 
     foreach my $member (@members) {
-        my $fileName = $member->fileName();           # in Unix format
-        $fileName =~ s{$pattern}{$dest};    # in Unix format
-                                            # convert to platform format:
-        $fileName = Archive::Zip::_asLocalName( $fileName, $volume );
+        my $fileName = $member->fileName();    # in Unix format
+        $fileName =~ s{$pattern}{$dest};       # in Unix format
+                                               # convert to platform format:
+        $fileName = Archive::Zip::_asLocalName($fileName, $volume);
         my $status = $member->extractToFileNamed($fileName);
         return $status if $status != AZ_OK;
     }
@@ -880,22 +865,21 @@ sub extractTree {
 sub updateMember {
     my $self = shift;
 
-    my ( $oldMember, $fileName );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($oldMember, $fileName);
+    if (ref($_[0]) eq 'HASH') {
         $oldMember = $_[0]->{memberOrZipName};
         $fileName  = $_[0]->{name};
-    }
-    else {
-        ( $oldMember, $fileName ) = @_;
+    } else {
+        ($oldMember, $fileName) = @_;
     }
 
-    if ( !defined($fileName) ) {
+    if (!defined($fileName)) {
         _error("updateMember(): missing fileName argument");
         return undef;
     }
 
     my @newStat = stat($fileName);
-    if ( !@newStat ) {
+    if (!@newStat) {
         _ioError("Can't stat $fileName");
         return undef;
     }
@@ -904,36 +888,36 @@ sub updateMember {
 
     my $memberName;
 
-    if ( ref($oldMember) ) {
+    if (ref($oldMember)) {
         $memberName = $oldMember->fileName();
-    }
-    else {
-        $oldMember = $self->memberNamed( $memberName = $oldMember )
-          || $self->memberNamed( $memberName =
-              _asZipDirName( $oldMember, $isDir ) );
+    } else {
+        $oldMember = $self->memberNamed($memberName = $oldMember)
+          || $self->memberNamed($memberName =
+              _asZipDirName($oldMember, $isDir));
     }
 
-    unless ( defined($oldMember)
+    unless (defined($oldMember)
         && $oldMember->lastModTime() == $newStat[9]
         && $oldMember->isDirectory() == $isDir
-        && ( $isDir || ( $oldMember->uncompressedSize() == $newStat[7] ) ) )
-    {
+        && ($isDir || ($oldMember->uncompressedSize() == $newStat[7]))) {
 
         # create the new member
-        my $newMember = $isDir
-          ? $self->ZIPMEMBERCLASS->newDirectoryNamed( $fileName, $memberName )
-          : $self->ZIPMEMBERCLASS->newFromFile( $fileName, $memberName );
+        my $newMember =
+            $isDir
+          ? Archive::Zip::Member->newDirectoryNamed($fileName, $memberName)
+          : Archive::Zip::Member->newFromFile($fileName, $memberName);
 
-        unless ( defined($newMember) ) {
+        unless (defined($newMember)) {
             _error("creation of member $fileName failed in updateMember()");
             return undef;
         }
 
         # replace old member or append new one
-        if ( defined($oldMember) ) {
-            $self->replaceMember( $oldMember, $newMember );
+        if (defined($oldMember)) {
+            $self->replaceMember($oldMember, $newMember);
+        } else {
+            $self->addMember($newMember);
         }
-        else { $self->addMember($newMember); }
 
         return $newMember;
     }
@@ -952,31 +936,31 @@ sub updateMember {
 sub updateTree {
     my $self = shift;
 
-    my ( $root, $dest, $pred, $mirror, $compressionLevel );
-    if ( ref( $_[0] ) eq 'HASH' ) {
+    my ($root, $dest, $pred, $mirror, $compressionLevel);
+    if (ref($_[0]) eq 'HASH') {
         $root             = $_[0]->{root};
         $dest             = $_[0]->{zipName};
         $pred             = $_[0]->{select};
         $mirror           = $_[0]->{mirror};
         $compressionLevel = $_[0]->{compressionLevel};
-    }
-    else {
-        ( $root, $dest, $pred, $mirror, $compressionLevel ) = @_;
+    } else {
+        ($root, $dest, $pred, $mirror, $compressionLevel) = @_;
     }
 
     return _error("root arg missing in call to updateTree()")
       unless defined($root);
     $dest = '' unless defined($dest);
-    $pred = sub { -r } unless defined($pred);
+    $pred = sub { -r }
+      unless defined($pred);
 
-    $dest = _asZipDirName( $dest, 1 );
-    my $rootZipName = _asZipDirName( $root, 1 );    # with trailing slash
+    $dest = _asZipDirName($dest, 1);
+    my $rootZipName = _asZipDirName($root, 1);    # with trailing slash
     my $pattern = $rootZipName eq './' ? '^' : "^\Q$rootZipName\E";
 
     my @files;
-    my $startDir = _untaintDir( cwd() );
+    my $startDir = _untaintDir(cwd());
 
-    return _error( 'undef returned by _untaintDir on cwd ', cwd() )
+    return _error('undef returned by _untaintDir on cwd ', cwd())
       unless $startDir;
 
     # This avoids chdir'ing in Find, in a way compatible with older
@@ -985,11 +969,11 @@ sub updateTree {
         local $main::_ = $File::Find::name;
         my $dir = _untaintDir($File::Find::dir);
         chdir($startDir);
-        push( @files, $File::Find::name ) if (&$pred);
+        push(@files, $File::Find::name) if (&$pred);
         chdir($dir);
     };
 
-    File::Find::find( $wanted, $root );
+    File::Find::find($wanted, $root);
 
     # Now @files has all the files that I could potentially be adding to
     # the zip. Only add the ones that are necessary.
@@ -1000,13 +984,13 @@ sub updateTree {
         my $isDir   = -d _;
 
         # normalize, remove leading ./
-        my $memberName = _asZipDirName( $fileName, $isDir );
-        if ( $memberName eq $rootZipName ) { $memberName = $dest }
-        else { $memberName =~ s{$pattern}{$dest} }
+        my $memberName = _asZipDirName($fileName, $isDir);
+        if ($memberName eq $rootZipName) { $memberName = $dest }
+        else                             { $memberName =~ s{$pattern}{$dest} }
         next if $memberName =~ m{^\.?/?$};    # skip current dir
 
         $done{$memberName} = 1;
-        my $changedMember = $self->updateMember( $memberName, $fileName );
+        my $changedMember = $self->updateMember($memberName, $fileName);
         $changedMember->desiredCompressionLevel($compressionLevel);
         return _error("updateTree failed to update $fileName")
           unless ref($changedMember);
@@ -1015,9 +999,9 @@ sub updateTree {
     # @done now has the archive names corresponding to all the found files.
     # If we're mirroring, delete all those members that aren't in @done.
     if ($mirror) {
-        foreach my $member ( $self->members() ) {
+        foreach my $member ($self->members()) {
             $self->removeMember($member)
-              unless $done{ $member->fileName() };
+              unless $done{$member->fileName()};
         }
     }
 
